@@ -1,7 +1,14 @@
+from __future__ import annotations
+
 import configparser
 import enum
 import os
 from contextlib import contextmanager
+from typing import Callable, Union, Type, TypeVar
+
+
+DefaultT = TypeVar('DefaultT')
+T = TypeVar('T')
 
 _config = None
 
@@ -15,7 +22,12 @@ class NoDefault():
     pass
 
 
-def get_config(section, key, default=NoDefault, type_=str):
+def get_config(
+    section: str,
+    key: str,
+    default: Union[Type[NoDefault], DefaultT] = NoDefault,
+    type_: Callable[[str], T] = str,
+) -> Union[T, DefaultT]:
     """Read the value of ``key`` from ``section`` of the test-pack
     configuration file.
 
@@ -36,12 +48,12 @@ def get_config(section, key, default=NoDefault, type_=str):
     the stb-tester device where the script is running. Values in the
     host-specific config file override values in ``.stbt.conf``. See
     `Configuration files
-    <https://stb-tester.com/manual/advanced-configuration#configuration-files>`__
+    <https://stb-tester.com/manual/configuration#configuration-files>`__
     for more details.
 
     Test scripts can use ``get_config`` to read tags that you specify at
     run-time: see `Automatic configuration keys
-    <https://stb-tester.com/manual/advanced-configuration#automatic-configuration-keys>`__.
+    <https://stb-tester.com/manual/configuration#automatic-configuration-keys>`__.
     For example::
 
         my_tag_value = stbt.get_config("result.tags", "my tag name")
