@@ -1,4 +1,4 @@
-# coding: utf-8
+from __future__ import annotations
 
 import errno
 import inspect
@@ -6,15 +6,22 @@ import os
 import re
 import warnings
 from functools import lru_cache
-from typing import overload, Tuple
+from typing import Optional, overload, Sequence, Tuple, TypeAlias, Union
 
 import cv2
 import numpy
+import numpy.typing
 
 from .logging import ddebug, debug, warn
 from .types import Region
 
 
+FrameT : TypeAlias = numpy.typing.NDArray[numpy.uint8]
+
+# Anything that load_image can take:
+ImageT : TypeAlias = Union[numpy.typing.NDArray[numpy.uint8], str]
+
+
 class Frame(numpy.ndarray):
     """A frame of video.
 
@@ -54,15 +61,15 @@ class Frame(numpy.ndarray):
         return repr(self)
 
     @property
-    def width(self):
+    def width(self) -> int:
         return self.shape[1]  # pylint:disable=unsubscriptable-object
 
     @property
-    def height(self):
+    def height(self) -> int:
         return self.shape[0]  # pylint:disable=unsubscriptable-object
 
     @property
-    def region(self):
+    def region(self) -> Region:
         return Region(0, 0, self.shape[1], self.shape[0])
 
 
@@ -126,15 +133,15 @@ class Image(numpy.ndarray):
         return repr(self)
 
     @property
-    def width(self):
+    def width(self) -> int:
         return self.shape[1]  # pylint:disable=unsubscriptable-object
 
     @property
-    def height(self):
+    def height(self) -> int:
         return self.shape[0]  # pylint:disable=unsubscriptable-object
 
     @property
-    def region(self):
+    def region(self) -> Region:
         return Region(0, 0, self.shape[1], self.shape[0])
 
 
@@ -186,15 +193,21 @@ class Color:
     def __init__(self, hexstring: str) -> None:
         ...
     @overload
-    def __init__(self, blue: int, green: int, red: int) -> None:
+    def __init__(self, blue: int, green: int, red: int,
+                 alpha: "Optional[int]" = None) -> None:
         ...
     @overload
-    def __init__(self, bgr: Tuple[int, int, int]) -> None:
+    def __init__(self, bgr: "Tuple[int, int, int]") -> None:
+        ...
+    @overload
+    def __init__(self, bgra: "Tuple[int, int, int, int]") -> None:
         ...
     def __init__(self, *args,
                  hexstring: str = None,
                  blue: int = None, green: int = None, red: int = None,
-                 bgr: Tuple[int, int, int] = None):
+                 alpha: int = None,
+                 bgr: "Tuple[int, int, int]" = None,
+                 bgra: "Tuple[int, int, int, int]" = None) -> None:
 
         self.array: numpy.ndarray  # BGR with shape (1, 1, 3) or BGRA (1, 1, 4)
 
@@ -214,8 +227,10 @@ class Color:
             self.array = Color._from_sequence(*args)  # pylint:disable=no-value-for-parameter
         elif not args and bgr is not None:
             self.array = Color._from_sequence(*bgr)
+        elif not args and bgra is not None:
+            self.array = Color._from_sequence(*bgra)
         elif not args and all(x is not None for x in (blue, green, red)):
-            self.array = Color._from_sequence(blue, green, red)
+            self.array = Color._from_sequence(blue, green, red, alpha)
 
         else:
             raise TypeError("Color: __init__() expected a Color, '#rrggbb' "
@@ -275,17 +290,20 @@ class Color:
         return (numpy.asarray(out, dtype=numpy.uint8)
                      .reshape((1, 1, len(channels))))
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"Color('{self.hexstring}')"
 
-    def __eq__(self, other):
+    def __eq__(self, other: "Color") -> bool:
         return isinstance(other, Color) and self.hexstring == other.hexstring
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         return hash(self.hexstring)
 
 
-def crop(frame, region):
+ColorT : TypeAlias = Union[Color, str, Tuple[int, int, int]]
+
+
+def crop(frame: FrameT, region: Region) -> FrameT:
     """Returns an image containing the specified region of ``frame``.
 
     :type frame: `stbt.Frame` or `numpy.ndarray`
@@ -321,7 +339,11 @@ def _image_region(image):
     return Region(0, 0, s[1], s[0])
 
 
-def load_image(filename, flags=None, color_channels=None) -> Image:
+def load_image(
+    filename: ImageT,
+    flags: Optional[Tuple[int]] = None,
+    color_channels: Optional[Sequence[int]] = None,
+) -> Image:
     """Find & read an image from disk.
 
     If given a relative filename, this will search in the directory of the
@@ -504,7 +526,7 @@ def _filename_repr(absolute_filename):
         return repr(_relative_filename(absolute_filename))
 
 
-def save_frame(image, filename):
+def save_frame(image: FrameT, filename: str):
     """Saves an OpenCV image to the specified file.
 
     Takes an image obtained from `get_frame` or from the `screenshot`
