@@ -1,4 +1,4 @@
-# coding: utf-8
+from __future__ import annotations
 
 import errno
 import glob
@@ -7,17 +7,21 @@ import re
 import shutil
 import subprocess
 from enum import IntEnum
+from typing import Dict, List, Optional, Union
 
 import cv2
 import numpy
 
 from . import imgproc_cache
 from .config import get_config
-from .imgutils import Color, crop, _frame_repr, _validate_region
+from .imgutils import Color, ColorT, crop, FrameT, _frame_repr, _validate_region
 from .logging import debug, ImageLogger, warn
 from .types import Region
 from .utils import LooseVersion, named_temporary_directory, to_unicode
 
+CorrectionsT = Dict[Union[re.Pattern, str], str]
+
+
 # Tesseract sometimes has a hard job distinguishing certain glyphs such as
 # ligatures and different forms of the same punctuation.  We strip out this
 # superfluous information improving matching accuracy with minimal effect on
@@ -118,11 +122,11 @@ class TextMatchResult():
     _fields = ("time", "match", "region", "frame", "text")
 
     def __init__(self, time, match, region, frame, text):
-        self.time = time
-        self.match = match
-        self.region = region
-        self.frame = frame
-        self.text = text
+        self.time: Optional[float] = time
+        self.match: bool = match
+        self.region: Region = region
+        self.frame: FrameT = frame
+        self.text: str = text
 
     def __bool__(self):
         return self.match
@@ -138,12 +142,21 @@ class TextMatchResult():
                 self.text))
 
 
-def ocr(frame=None, region=Region.ALL,
-        mode=OcrMode.PAGE_SEGMENTATION_WITHOUT_OSD,
-        lang=None, tesseract_config=None, tesseract_user_words=None,
-        tesseract_user_patterns=None, upsample=True, text_color=None,
-        text_color_threshold=None, engine=None, char_whitelist=None,
-        corrections=None):
+def ocr(
+    frame: FrameT = None,
+    region: Region = Region.ALL,
+    mode: OcrMode = OcrMode.PAGE_SEGMENTATION_WITHOUT_OSD,
+    lang: str = None,
+    tesseract_config: Optional[Dict[str, Union[bool, str, int]]] = None,
+    tesseract_user_words: Union[List[str], str] = None,
+    tesseract_user_patterns: Union[List[str], str] = None,
+    upsample: bool = True,
+    text_color: ColorT = None,
+    text_color_threshold: float = None,
+    engine: Optional[OcrEngine] = None,
+    char_whitelist: str = None,
+    corrections: Optional[CorrectionsT] = None,
+):
     r"""Return the text present in the video frame as a Unicode string.
 
     Perform OCR (Optical Character Recognition) using the "Tesseract"
@@ -280,11 +293,20 @@ def ocr(frame=None, region=Region.ALL,
     return text
 
 
-def match_text(text, frame=None, region=Region.ALL,
-               mode=OcrMode.PAGE_SEGMENTATION_WITHOUT_OSD, lang=None,
-               tesseract_config=None, case_sensitive=False, upsample=True,
-               text_color=None, text_color_threshold=None,
-               engine=None, char_whitelist=None):
+def match_text(
+    text: str,
+    frame: FrameT = None,
+    region: Region = Region.ALL,
+    mode: OcrMode = OcrMode.PAGE_SEGMENTATION_WITHOUT_OSD,
+    lang: str = None,
+    tesseract_config: Optional[Dict[str, Union[bool, str, int]]] = None,
+    case_sensitive: bool = False,
+    upsample: bool = True,
+    text_color: ColorT = None,
+    text_color_threshold: float = None,
+    engine: Optional[OcrEngine] = None,
+    char_whitelist: str = None,
+) -> TextMatchResult:
     """Search for the specified text in a single video frame.
 
     This can be used as an alternative to `match`, searching for text instead
@@ -372,7 +394,9 @@ def match_text(text, frame=None, region=Region.ALL,
 PatternType = type(re.compile(""))
 
 
-def apply_ocr_corrections(text, corrections=None):
+def apply_ocr_corrections(
+        text: str,
+        corrections: Optional[CorrectionsT] = None) -> str:
     """Applies the same corrections as `stbt.ocr`'s ``corrections`` parameter.
 
     This is available as a separate function so that you can use it to
@@ -414,7 +438,7 @@ def _apply_ocr_corrections(text, corrections):
 global_ocr_corrections = {}
 
 
-def set_global_ocr_corrections(corrections):
+def set_global_ocr_corrections(corrections: CorrectionsT):
     """Specify default OCR corrections that apply to all calls to `stbt.ocr`
     and `stbt.apply_ocr_corrections`.
 
