@@ -1,13 +1,21 @@
-"""Copyright 2015-2019 Stb-tester.com Ltd."""
+"""Copyright © 2015-2022 Stb-tester.com Ltd."""
+
+from __future__ import annotations
 
-import functools
 import inspect
+from typing import Callable, TypeVar
 
 from .logging import debug
 
 
-def wait_until(callable_, timeout_secs=10, interval_secs=0, predicate=None,
-               stable_secs=0):
+T = TypeVar("T")
+
+
+def wait_until(callable_: Callable[[], T],
+               timeout_secs: float = 10,
+               interval_secs: float = 0,
+               predicate: Callable[[T], bool] = None,
+               stable_secs: float = 0) -> T | None:
     """Wait until a condition becomes true, or until a timeout.
 
     Calls ``callable_`` repeatedly (with a delay of ``interval_secs`` seconds
@@ -133,18 +141,19 @@ def wait_until(callable_, timeout_secs=10, interval_secs=0, predicate=None,
 def _callable_description(callable_):
     """Helper to provide nicer debug output when `wait_until` fails.
 
+    >>> import functools
     >>> _callable_description(wait_until)
     'wait_until'
     >>> _callable_description(
     ...     lambda: stbt.press("OK"))
     '    lambda: stbt.press("OK"))\\n'
     >>> _callable_description(functools.partial(eval, globals={}))
-    'eval'
+    'functools.partial(<built-in function eval>, globals={})'
     >>> _callable_description(
     ...     functools.partial(
     ...         functools.partial(eval, globals={}),
     ...         locals={}))
-    'eval'
+    'functools.partial(<built-in function eval>, globals={}, locals={})'
     >>> class T():
     ...     def __call__(self): return True;
     >>> _callable_description(T())
@@ -158,7 +167,5 @@ def _callable_description(callable_):
             except IOError:
                 pass
         return name
-    elif isinstance(callable_, functools.partial):
-        return _callable_description(callable_.func)
     else:
         return repr(callable_)
